tonalitytools.TonalFunction
===========================

.. inheritance-diagram:: abjad.tools.tonalitytools.TonalFunction.TonalFunction.TonalFunction
   :private-bases:

.. autoclass:: abjad.tools.tonalitytools.TonalFunction.TonalFunction.TonalFunction

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.tonalitytools.TonalFunction.TonalFunction.TonalFunction.bass_scale_degree

.. autoattribute:: abjad.tools.tonalitytools.TonalFunction.TonalFunction.TonalFunction.extent

.. autoattribute:: abjad.tools.tonalitytools.TonalFunction.TonalFunction.TonalFunction.figured_bass_string

.. autoattribute:: abjad.tools.tonalitytools.TonalFunction.TonalFunction.TonalFunction.inversion

.. autoattribute:: abjad.tools.tonalitytools.TonalFunction.TonalFunction.TonalFunction.markup

.. autoattribute:: abjad.tools.tonalitytools.TonalFunction.TonalFunction.TonalFunction.quality

.. autoattribute:: abjad.tools.tonalitytools.TonalFunction.TonalFunction.TonalFunction.root_scale_degree

.. autoattribute:: abjad.tools.tonalitytools.TonalFunction.TonalFunction.TonalFunction.scale_degree

.. autoattribute:: abjad.tools.tonalitytools.TonalFunction.TonalFunction.TonalFunction.suspension

.. autoattribute:: abjad.tools.tonalitytools.TonalFunction.TonalFunction.TonalFunction.symbolic_string

Special Methods
---------------

.. automethod:: abjad.tools.tonalitytools.TonalFunction.TonalFunction.TonalFunction.__delattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.tonalitytools.TonalFunction.TonalFunction.TonalFunction.__eq__

.. automethod:: abjad.tools.tonalitytools.TonalFunction.TonalFunction.TonalFunction.__ge__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.tonalitytools.TonalFunction.TonalFunction.TonalFunction.__gt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.tonalitytools.TonalFunction.TonalFunction.TonalFunction.__hash__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.tonalitytools.TonalFunction.TonalFunction.TonalFunction.__le__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.tonalitytools.TonalFunction.TonalFunction.TonalFunction.__lt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.tonalitytools.TonalFunction.TonalFunction.TonalFunction.__ne__

.. automethod:: abjad.tools.tonalitytools.TonalFunction.TonalFunction.TonalFunction.__repr__

.. automethod:: abjad.tools.tonalitytools.TonalFunction.TonalFunction.TonalFunction.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.tonalitytools.TonalFunction.TonalFunction.TonalFunction.__str__

   .. note:: Inherited from `__builtin__.object`
